@@ -8,9 +8,10 @@ kcv.svm <-
     if (!is.factor(y)) {
       y <- factor(y)
     }
-    if (length(unique(y)) == 1L)
+    if (length(unique(y)) == 1L) {
       stop("Input 'y' must contain some variation (i.e., cannot contain \n
            only a single type of label).")
+    }
     if (is.null(nfolds)) {
       nfolds <- 10
     } else {
